R/data-sf911.R
sf911.RdThe data was downloaded from https://data.sfgov.org/Public-Safety/Fire-Department-and-Emergency-Medical-Services-Dis/nuek-vuh3/about_data/ and contains all fire units' responses to 911 calls from the city of San Francisco's Computer-Aided Dispatch (“CAD”) system with a call date in 2025. The columns of this dataset are a subset of those in the original data and the rows were rearranged for educational purposes.
sf911A data frame with 369,089 rows and 28 variables. Each row represents a response, and since most calls involve multiple units, there are multiple records for each call number.
A unique 9-digit number assigned by the 911 Dispatch Center (DEM) to this call. These number are used for both Police and Fire calls.
Unit Identifier. For example E01 for Engine 1 or T01 for Truck 1.
A unique 8-digit number assigned by DEM to this Fire incident.
Type of call the incident falls into. See in metadata section for more information.
Date the call is received at the 911 Dispatch Center. Used for reporting purposes.
Watch date when the call is received. Watch date starts at 0800 each morning and ends at 0800 the next day.
Date and time of call is received at the 911 Dispatch Center.
Date and time the 911 operator submits the entry of the initial call information into the CAD system
Date and time the 911 operator dispatches this unit to the call.
Date and time this unit acknowledges the dispatch and records that the unit is en route to the location of the call.
Date and time the unit records arriving to the location of the incident.
If this unit is an ambulance, date and time the unit begins the transport to the hospital.
If this unit is an ambulance, date and time the unit arrives to the hospital.
Disposition of the call (Code). For example TH2: Transport to Hospital - Code 2, FIR: Resolved by Fire Department
Date and time this unit is not longer assigned to this call and it is available for another dispatch.
Address of intersection or call box point associated with incident (obfuscated address to protect caller privacy).
City of incident
Zipcode of incident.
Initial call priority (Code 2: Non-Emergency or Code 3:Emergency).
Call priority once all information has been asssessed (Code 2: Non-Emergency or Code 3:Emergency).
Final call priority (Code 2: Non-Emergency or Code 3:Emergency).
Does this unit includes ALS (Advance Life Support) resources? Is there a paramedic in this unit?
Call types are divided into four main groups: Fire, Alarm, Potential Life Threatening and Non Life Threatening.
There are five levels of fire alarms (1-5). The number of alarms indicates the number of resources required in an incident. This number is a combination of engines, trucks, rescue squads, chiefs and EMS units.
Type of unit responding.
A number that indicates the order this unit was assigned to this call.
San Francisco Neighborhood associated with the incident address.
Latitude and Longitude for the call.
San Francisco Department of Emergency Management (2026). https://data.sfgov.org/Public-Safety/Fire-Department-and-Emergency-Medical-Services-Dis/nuek-vuh3/about_data/.